@@ -1,6 +1,7 @@
-(function($) {
-  $(function() {
-    if ($("#edit-pathauto-perform-alias").attr("checked")) {
+// $Id: pathauto.js,v 1.1.2.4 2008/03/06 02:55:12 greggles Exp $
+if (Drupal.jsEnabled) {
+  $(document).ready(function() {
+    if ($("#edit-pathauto-perform-alias").size() && $("#edit-pathauto-perform-alias").attr("checked")) {
       // Disable input and hide its description.
       $("#edit-path").attr("disabled","disabled");
       $("//#edit-path ~ div[@class=description]").hide(0);
@@ -19,4 +20,4 @@
       }
     });
   });
-})(jQuery);
+}
